@@ -7,17 +7,19 @@
 # Read Comics Free [EN] (disabled)
 # Xoxocomics [EN]
 
-from bs4 import BeautifulSoup
-import requests
 from urllib.parse import parse_qs
 from urllib.parse import urlparse
 
+from bs4 import BeautifulSoup
+import requests
+
+from komikku.consts import USER_AGENT
 from komikku.servers import Server
-from komikku.servers import USER_AGENT
 from komikku.servers.utils import convert_date_string
 from komikku.servers.utils import get_soup_element_inner_text
 from komikku.utils import get_buffer_mime_type
 from komikku.utils import is_number
+from komikku.webview import CompleteChallenge
 
 # WPComics Wordpress theme
 
@@ -45,12 +47,13 @@ class WPComics(Server):
     results_last_chapter_lastest_updates_link_selector: str = None
 
     def __init__(self):
-        if self.session is None:
+        if self.session is None and not self.has_cf:
             self.session = requests.Session()
             self.session.headers = {
                 'User-Agent': USER_AGENT,
             }
 
+    @CompleteChallenge()
     def get_manga_data(self, initial_data):
         """
         Returns comic data by scraping manga HTML page content
@@ -145,6 +148,7 @@ class WPComics(Server):
 
         return data
 
+    @CompleteChallenge()
     def get_manga_chapter_data(self, manga_slug, manga_name, chapter_slug, chapter_url):
         """
         Returns comic chapter data
@@ -173,6 +177,7 @@ class WPComics(Server):
 
         return data
 
+    @CompleteChallenge()
     def get_manga_chapter_page_image(self, manga_slug, manga_name, chapter_slug, page):
         """
         Returns chapter page scan (image) content
@@ -202,6 +207,7 @@ class WPComics(Server):
         """
         return self.manga_url.format(slug)
 
+    @CompleteChallenge()
     def get_latest_updates(self):
         """
         Returns daily updates
@@ -238,6 +244,7 @@ class WPComics(Server):
 
         return results
 
+    @CompleteChallenge()
     def get_most_populars(self):
         """
         Returns popular comics
@@ -272,6 +279,7 @@ class WPComics(Server):
 
         return results
 
+    @CompleteChallenge()
     def search(self, term):
         r = self.session.get(
             self.search_url,
