@@ -36,7 +36,6 @@ from gi.repository import Gtk
 from gi.repository.GdkPixbuf import Pixbuf
 from gi.repository.GdkPixbuf import PixbufAnimation
 
-from komikku.consts import PIXBUF_ANIMATION
 from komikku.consts import REQUESTS_TIMEOUT
 
 logger = logging.getLogger('komikku')
@@ -55,6 +54,24 @@ def check_cmdline_tool(cmd):
         return p.returncode == 0, out.decode('utf-8').strip()
 
 
+def concat_images_vertically(*args: Image):
+    """
+    Concat vertically a list of PIL images (same width)
+    """
+    h = 0
+    for img in args:
+        h += img.height
+
+    dst = Image.new('RGB', (args[0].width, h))
+
+    position = 0
+    for img in args:
+        dst.paste(img, (0, position))
+        position += img.height
+
+    return dst
+
+
 def convert_and_resize_image(buffer, width, height, keep_aspect_ratio=True, dominant_color=True, format='JPEG'):
     """Convert and resize an image (except animated GIF)
 
@@ -597,7 +614,7 @@ class CoverLoader(GObject.GObject):
 
         try:
             stream = Gio.MemoryInputStream.new_from_data(data, None)
-            if info['is_animated'] and not static_animation and PIXBUF_ANIMATION:
+            if info['is_animated'] and not static_animation:
                 pixbuf = PixbufAnimation.new_from_stream(stream)
             else:
                 pixbuf = Pixbuf.new_from_stream(stream)
@@ -616,7 +633,7 @@ class CoverLoader(GObject.GObject):
             return None
 
         try:
-            if info['is_animated'] and not static_animation and PIXBUF_ANIMATION:
+            if info['is_animated'] and not static_animation:
                 pixbuf = PixbufAnimation.new_from_file(path)
             else:
                 pixbuf = Pixbuf.new_from_file(path)
